//
//  AdvancedController.m
//  JOperateDemo
//
//  Created by ys on 2021/11/23.
//

#import "AdvancedController.h"
#import "JOPERATEPopView.h"

@interface AdvancedController ()<UITableViewDelegate, UITableViewDataSource>

@property(nonatomic, strong) NavBar *navbar;
@property(nonatomic, strong) UITableView *tableView;
@property(nonatomic, strong) NSMutableDictionary *dataSource;

@end

@implementation AdvancedController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.navbar = [[NavBar alloc] initWithTitle:@"高级功能" delegate:self withBack:YES];
    [self.view addSubview:self.navbar];
    self.view.backgroundColor = UIColor.whiteColor;
    
    [self layout];
    [self loadData];
}

- (void)layout {
    self.tableView = [[UITableView alloc] init];
    self.tableView.delegate = self;
    self.tableView.dataSource = self;
    self.tableView.separatorStyle = UITableViewCellSeparatorStyleNone;
    [self.tableView registerClass:[UITableViewCell class] forCellReuseIdentifier:@"cell"];
    [self.view addSubview:self.tableView];
    
    [self.tableView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(self.navbar.mas_bottom);
        make.left.width.bottom.equalTo(self.view);
    }];
}

- (void)loadData {
    [JOPERATEService userData:^(NSInteger code, NSDictionary<NSString *,id> * _Nonnull data) {
        if (!code &&  data) {
            NSLog(@"userData %@",data);
            dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(0 * NSEC_PER_SEC)), dispatch_get_main_queue(), ^{
                self.dataSource = [NSMutableDictionary dictionaryWithDictionary:data];
                NSArray *channels = self.dataSource[@"channels"];
                NSMutableArray *newChannels = [[NSMutableArray alloc] init];
                for (int i = 0; i < channels.count; ++i) {
                    NSDictionary* channel = channels[i];
                    NSArray *allKeys = [channel[@"contactValues"] allKeys];
                    for (int j = 0; j < [channel[@"contactValues"] count]; ++j) {
                        NSMutableDictionary *newChannel = [channel mutableCopy];
                        newChannel[@"channelvalue"] = channel[@"contactValues"][allKeys[j]];
                        newChannel[@"channelkey"] = allKeys[j];
                        newChannel[@"channelid"] = channel[@"channelid"];
                        newChannel[@"type"] = channel[@"type"];
                        newChannel[@"channelname"] = [channel[@"channelname"] stringByAppendingFormat:@" - %@", allKeys[j]];
                        [newChannels addObject:newChannel];
                    }
                }
                self.dataSource[@"channels"] = newChannels;
                [self.tableView reloadData];
            });
        }
    }];
}


- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell * cell = [tableView dequeueReusableCellWithIdentifier:@"cell"];
    cell.selectionStyle = UITableViewCellSelectionStyleNone;
    [cell.contentView.subviews makeObjectsPerformSelector:@selector(removeFromSuperview)];
    NSString * icon = @"";
    NSString * title = @"";
    switch (indexPath.row) {
        case 0:
        {
            icon = @"自定义事件";
            title = @"自定义行为事件";
            NSArray *events = self.dataSource[@"events"];
            NSInteger eventRow = 1 + ([events count] - 1)/2;
            UIView* garyBack = [[UIView alloc] init];
            garyBack.frame = CGRectMake(Scale(16), Scale(52), Scale(343), Scale(29+34*eventRow+(eventRow - 1)*12));
            garyBack.layer.cornerRadius = 4;
            garyBack.backgroundColor = kUIColorFromRGB(0xF6F7F8);
            [cell.contentView addSubview:garyBack];
            
            UIImageView* icon2View =  [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"首页提示"]];
            icon2View.frame = CGRectMake(Scale(18), Scale(11), Scale(16), Scale(16));
            [cell.contentView addSubview:icon2View];
            [icon2View mas_makeConstraints:^(MASConstraintMaker *make) {
                make.top.equalTo(garyBack.mas_bottom).offset(Scale(11));
                make.left.equalTo(cell.contentView).offset(Scale(18));
                make.size.mas_equalTo(Scale(14));
            }];
            
            UILabel *descLabel = [[UILabel alloc] init];
            descLabel.numberOfLines = 0;
            descLabel.attributedText = [[NSMutableAttributedString alloc] initWithString:@"显示事件列表前8个自定义事件，点击上报相应事件至运营增长 -调试数据"
                                                                              attributes: @{NSFontAttributeName: [UIFont systemFontOfSize:12],  NSForegroundColorAttributeName: kUIColorFromRGB(0x8D939D)}];
            [cell.contentView addSubview:descLabel];
            [descLabel mas_makeConstraints:^(MASConstraintMaker *make) {
                make.top.equalTo(garyBack.mas_bottom).offset(Scale(10));
                make.left.equalTo(cell.contentView).offset(Scale(32));
                make.right.equalTo(cell.contentView.mas_right).offset(-Scale(11));
            }];
            if (!events.count) {
                garyBack.frame = CGRectMake(Scale(16), Scale(52), Scale(343), Scale(201));
                icon2View.image = [UIImage imageNamed:@"无数据背景"];
                [icon2View mas_updateConstraints:^(MASConstraintMaker *make) {
                    make.top.equalTo(garyBack.mas_top).offset(Scale(43));
                    make.left.equalTo(cell.contentView).offset(Scale(147));
                    make.size.mas_equalTo(Scale(80));
                }];
                
                descLabel.attributedText = [[NSMutableAttributedString alloc] initWithString:@"该项目未创建任一自定义事件，请在「数据中心-事件管理」创建"
                                                                                  attributes: @{NSFontAttributeName: [UIFont systemFontOfSize:13],  NSForegroundColorAttributeName: kUIColorFromRGB(0x8D939D)}];
                descLabel.textAlignment = NSTextAlignmentCenter;
                [descLabel mas_updateConstraints:^(MASConstraintMaker *make) {
                    make.top.equalTo(garyBack.mas_top).offset(Scale(143));
                    make.left.equalTo(cell.contentView).offset(Scale(58));
                    make.right.equalTo(cell.contentView.mas_right).offset(-Scale(58));
                }];
            } else {
                for (int i = 0; i < events.count; ++i) {
                    UILabel * eventLabel = [[UILabel alloc] init];
                    eventLabel.backgroundColor = kUIColorFromRGB(0xE4E6E8);
                    eventLabel.textColor = kUIColorFromRGB(0x485162);
                    eventLabel.font = [UIFont systemFontOfSize:Scale(12)];
                    eventLabel.layer.cornerRadius = Scale(17);
                    eventLabel.layer.masksToBounds = YES;
                    eventLabel.textAlignment = NSTextAlignmentCenter;
                    [cell.contentView addSubview:eventLabel];
                    eventLabel.frame = CGRectMake(i%2 == 1 ? Scale(193):Scale(30) , Scale(46*(i/2) + 68), Scale(150), Scale(34));
                    eventLabel.userInteractionEnabled = YES;
                    eventLabel.text = events[i][@"displayName"];
                    eventLabel.tag = i;
                    [eventLabel addGestureRecognizer:[[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(eventTap:)]];
                }
            }
        }
            break;
        case 1:
        {
            icon = @"设置等级标识";
            title = @"设置等级标识";
            NSArray *tags = self.dataSource[@"tag"];
            for (int i = 0; i < tags.count; ++i) {
                UILabel *label = [[UILabel alloc] init];
                label.frame = CGRectMake(Scale(16), Scale(64 + i*60), Scale(130), Scale(20));
                [cell.contentView addSubview:label];
                label.attributedText = [[NSMutableAttributedString alloc] initWithString:tags[i][@"displayName"] attributes: @{NSFontAttributeName: [UIFont systemFontOfSize: 14],NSForegroundColorAttributeName: kUIColorFromRGB(0x6B7381)}];
               
                UILabel *valueLabel = [[UILabel alloc] init];
                valueLabel.textColor = kUIColorFromRGB(0x253044);
                valueLabel.font = [UIFont systemFontOfSize:12.0];
                valueLabel.textAlignment = NSTextAlignmentRight;
                valueLabel.text = [tags[i][@"identityValues"] componentsJoinedByString:@","];
                [cell.contentView addSubview:valueLabel];
                
                [valueLabel mas_makeConstraints:^(MASConstraintMaker *make) {
                    make.height.equalTo(label.mas_height);
                    make.centerY.equalTo(label.mas_centerY);
                    make.right.equalTo(cell.contentView).offset(-Scale(32));
                    make.width.lessThanOrEqualTo(@(Scale(200)));
                }];
            
                UIButton *editBtn = [[UIButton alloc] init];
                editBtn.tag = i;
                [editBtn addTarget:self action:@selector(editUserID:) forControlEvents:UIControlEventTouchUpInside];
                [editBtn setImage:[UIImage imageNamed:@"编辑"] forState:UIControlStateNormal];
                [cell.contentView addSubview:editBtn];
                [editBtn mas_makeConstraints:^(MASConstraintMaker *make) {
                    make.width.height.mas_equalTo(Scale(20));
                    make.centerY.equalTo(valueLabel.mas_centerY);
                    make.right.equalTo(cell.contentView.mas_right).offset(Scale(-12));
                }];
                
                if (!valueLabel.text || valueLabel.text.length < 1) {
                    valueLabel.textColor = kUIColorFromRGB(0x8D939D);
                    valueLabel.text = @"请填写";
                    [editBtn setImage:[UIImage imageNamed:@"右箭头"] forState:UIControlStateNormal];
                }
                
                UIView *line = [[UIView alloc] init];
                line.layer.backgroundColor = [UIColor colorWithRed:238/255.0 green:239/255.0 blue:247/255.0 alpha:1.0].CGColor;
                [cell.contentView addSubview:line];
                [line mas_makeConstraints:^(MASConstraintMaker *make) {
                    make.height.mas_equalTo(Scale(1));
                    make.left.equalTo(cell.contentView.mas_left).offset(Scale(16));
                    make.right.equalTo(cell.contentView.mas_right).offset(Scale(-16));
                    make.top.equalTo(cell.contentView).offset(Scale(44 + 60*(i+1)));
                }];
            }
            
            break;
        }
        case 2:
        {
            icon = @"设置触达通道";
            title = @"设置触达通道";
            NSArray *channels = self.dataSource[@"channels"];
            if (!channels.count) {
                UIImageView* iconView =  [[UIImageView alloc]  initWithImage:[UIImage imageNamed:@"无数据背景"]];
                iconView.frame = CGRectMake(Scale(16), Scale(52), Scale(343), Scale(201));
                [cell.contentView addSubview:iconView];
                [iconView mas_makeConstraints:^(MASConstraintMaker *make) {
                    make.top.equalTo(cell.contentView.mas_top).offset(Scale(54));
                    make.left.equalTo(cell.contentView).offset(Scale(147));
                    make.size.mas_equalTo(Scale(80));
                }];
                
                
                UILabel *descLabel = [[UILabel alloc] init];
                descLabel.numberOfLines = 0;
                descLabel.textAlignment = NSTextAlignmentCenter;
                descLabel.attributedText = [[NSMutableAttributedString alloc] initWithString:@"该项目未创建任一触达通道，请在「数据中心-数据通道连接」创建"
                                                                                  attributes: @{NSFontAttributeName: [UIFont systemFontOfSize:13],  NSForegroundColorAttributeName: kUIColorFromRGB(0x8D939D)}];
                [cell.contentView addSubview:descLabel];
                [descLabel mas_makeConstraints:^(MASConstraintMaker *make) {
                    make.top.equalTo(cell.contentView.mas_top).offset(Scale(154));
                    make.left.equalTo(cell.contentView).offset(Scale(58));
                    make.right.equalTo(cell.contentView.mas_right).offset(-Scale(58));
                }];
            } else {
                for (int i = 0; i < channels.count; ++i) {
                    
                    UIImageView *icon = [[UIImageView alloc] initWithFrame:CGRectMake(Scale(16), Scale(70 + i*74), Scale(33), Scale(33))];
                    NSString *name = channels[i][@"channelname"];
                    NSString *type = channels[i][@"type"];
                    
                    if ([type isEqualToString:@"WECHATOA"]) {
                        icon.image = [UIImage imageNamed:@"微信公众号"];
                    } else if ([type isEqualToString:@"WECHATTMP"]) {
                        icon.image = [UIImage imageNamed:@"微信小程序"];
                    } else if ([type isEqualToString:@"PUSH"]) {
                        icon.image = [UIImage imageNamed:@"app通知"];
                    } else if ([type isEqualToString:@"EMAIL"]) {
                        icon.image = [UIImage imageNamed:@"邮件"];
                    } else if ([type isEqualToString:@"SMS"]) {
                        icon.image = [UIImage imageNamed:@"短信"];
                    } else if ([type isEqualToString:@"DINGTALK"]) {
                        icon.image = [UIImage imageNamed:@"钉钉"];
                    } else if ([type isEqualToString:@"ALIPAYLIFE"]) {
                        icon.image = [UIImage imageNamed:@"支付宝"];
                    }
                    [cell.contentView addSubview:icon];
                    
                    UILabel *label = [[UILabel alloc] init];
                    label.frame = CGRectMake(Scale(59), Scale(68 + i*74), Scale(130), Scale(20));
                    [cell.contentView addSubview:label];
                    label.attributedText = [[NSMutableAttributedString alloc] initWithString:name attributes: @{NSFontAttributeName: [UIFont systemFontOfSize: 14],NSForegroundColorAttributeName: kUIColorFromRGB(0x253044)}];

                    UILabel *desclabel = [[UILabel alloc] init];
                    desclabel.frame = CGRectMake(Scale(59), Scale(87 + i*74), Scale(130), Scale(20));
                    [cell.contentView addSubview:desclabel];
                    desclabel.attributedText = [[NSMutableAttributedString alloc] initWithString:[@"ID: " stringByAppendingString:channels[i][@"channelid"]] attributes: @{NSFontAttributeName: [UIFont systemFontOfSize: 14],NSForegroundColorAttributeName: kUIColorFromRGB(0x6B7381)}];
                   
                    UILabel *valueLabel = [[UILabel alloc] init];
                    //8D939D
                    valueLabel.textColor = kUIColorFromRGB(0x253044);
                    valueLabel.font = [UIFont systemFontOfSize:12.0];
                    valueLabel.textAlignment = NSTextAlignmentRight;
                    valueLabel.text = channels[i][@"channelvalue"];
                    [cell.contentView addSubview:valueLabel];
                    
                    [valueLabel mas_makeConstraints:^(MASConstraintMaker *make) {
                        make.height.equalTo(label.mas_height);
                        make.centerY.equalTo(icon.mas_centerY);
                        make.width.lessThanOrEqualTo(@(Scale(150)));
                        if (![name isEqualToString:@"PUSH"]) {
                            make.right.equalTo(cell.contentView).offset(-Scale(32));
                        } else {
                            make.right.equalTo(cell.contentView).offset(-Scale(16));
                        }
                    }];
                    if (![name isEqualToString:@"PUSH"] || !valueLabel.text || valueLabel.text.length < 1) {
                        UIButton *editBtn = [[UIButton alloc] init];
                        editBtn.tag = i;
                        [editBtn addTarget:self action:@selector(editUserChannels:) forControlEvents:UIControlEventTouchUpInside];
                        [editBtn setImage:[UIImage imageNamed:@"编辑"] forState:UIControlStateNormal];
                        [cell.contentView addSubview:editBtn];
                        [editBtn mas_makeConstraints:^(MASConstraintMaker *make) {
                            make.width.height.mas_equalTo(Scale(20));
                            make.centerY.equalTo(valueLabel.mas_centerY);
                            make.right.equalTo(cell.contentView.mas_right).offset(Scale(-12));
                        }];
                        if (!valueLabel.text || valueLabel.text.length < 1) {
                            valueLabel.textColor = kUIColorFromRGB(0x8D939D);
                            valueLabel.text = @"请填写";
                            [editBtn setImage:[UIImage imageNamed:@"右箭头"] forState:UIControlStateNormal];
                        }
                    }
                    
                    UIView *line = [[UIView alloc] init];
                    line.layer.backgroundColor = [UIColor colorWithRed:238/255.0 green:239/255.0 blue:247/255.0 alpha:1.0].CGColor;
                    [cell.contentView addSubview:line];
                    [line mas_makeConstraints:^(MASConstraintMaker *make) {
                        make.height.mas_equalTo(Scale(1));
                        make.left.equalTo(cell.contentView.mas_left).offset(Scale(16));
                        make.right.equalTo(cell.contentView.mas_right).offset(Scale(-16));
                        make.top.equalTo(cell.contentView).offset(Scale(44 + 76*(i+1)));
                    }];
                }
            }
            break;
        }
        case 3:
        {
            icon = @"设置用户属性";
            title = @"设置用户属性";
            NSArray *userProperties = self.dataSource[@"user"];
            
            for (int i = 0; i < userProperties.count; ++i) {
                NSInteger type = [userProperties[i][@"type"] integerValue];
                UILabel *label = [[UILabel alloc] init];
                label.frame = CGRectMake(Scale(16), Scale(64 + i*60), Scale(130), Scale(20));
                [cell.contentView addSubview:label];
                label.attributedText = [[NSMutableAttributedString alloc] initWithString:userProperties[i][@"displayName"] attributes: @{NSFontAttributeName: [UIFont systemFontOfSize: 14],NSForegroundColorAttributeName: kUIColorFromRGB(0x6B7381)}];
               
                UILabel *valueLabel = [[UILabel alloc] init];
                valueLabel.textColor = kUIColorFromRGB(0x253044);
                valueLabel.font = [UIFont systemFontOfSize:12.0];
                valueLabel.textAlignment = NSTextAlignmentRight;
                if ([userProperties[i][@"value"] isKindOfClass:[NSArray class]]) {
                    valueLabel.text = [userProperties[i][@"value"] componentsJoinedByString:@","];
                } else {
                    if ([userProperties[i][@"value"] isKindOfClass:[NSString class]]) {
                        if ([userProperties[i][@"datatype"] isEqualToString:@"datetime"]) {
                            valueLabel.text = [self timeintervalToStr:userProperties[i][@"value"]];
                        } else {
                            valueLabel.text = userProperties[i][@"value"];
                        }
                    } else {
                        valueLabel.text = [NSString stringWithFormat:@"%@", userProperties[i][@"value"]];
                    }
                }
                
                [cell.contentView addSubview:valueLabel];
                
                [valueLabel mas_makeConstraints:^(MASConstraintMaker *make) {
                    make.height.equalTo(label.mas_height);
                    make.centerY.equalTo(label.mas_centerY);
                    make.width.lessThanOrEqualTo(@(Scale(200)));
                    if (type != 3 || !valueLabel.text || valueLabel.text.length < 1) {
                        make.right.equalTo(cell.contentView).offset(-Scale(32));
                    } else {
                        make.right.equalTo(cell.contentView).offset(-Scale(16));
                    }
                }];
                if (type != 3 || !valueLabel.text || valueLabel.text.length < 1) {
                    UIButton *editBtn = [[UIButton alloc] init];
                    editBtn.tag = i;
                    [editBtn addTarget:self action:@selector(editUserProperties:) forControlEvents:UIControlEventTouchUpInside];
                    [editBtn setImage:[UIImage imageNamed:@"编辑"] forState:UIControlStateNormal];
                    [cell.contentView addSubview:editBtn];
                    [editBtn mas_makeConstraints:^(MASConstraintMaker *make) {
                        make.width.height.mas_equalTo(Scale(20));
                        make.centerY.equalTo(valueLabel.mas_centerY);
                        make.right.equalTo(cell.contentView.mas_right).offset(Scale(-12));
                    }];
                    
                    [editBtn setImage:[UIImage imageNamed:@"右箭头"] forState:UIControlStateNormal];

                }
                
                if (!valueLabel.text || valueLabel.text.length < 1) {
                    valueLabel.textColor = kUIColorFromRGB(0x8D939D);
                    valueLabel.text = @"请填写";

                }
                
                UIView *line = [[UIView alloc] init];
                line.layer.backgroundColor = [UIColor colorWithRed:238/255.0 green:239/255.0 blue:247/255.0 alpha:1.0].CGColor;
                [cell.contentView addSubview:line];
                [line mas_makeConstraints:^(MASConstraintMaker *make) {
                    make.height.mas_equalTo(Scale(1));
                    make.left.equalTo(cell.contentView.mas_left).offset(Scale(16));
                    make.right.equalTo(cell.contentView.mas_right).offset(Scale(-16));
                    make.top.equalTo(cell.contentView).offset(Scale(44 + 60*(i+1)));
                }];
            }
            break;
        }
    }
    
    UIImageView* icon1View =  [[UIImageView alloc]  initWithImage:[UIImage imageNamed:icon]];
    icon1View.frame = CGRectMake(Scale(16), Scale(17), Scale(20), Scale(20));
    [cell.contentView addSubview:icon1View];
    
    UILabel *titleLabel = [[UILabel alloc] init];
    titleLabel.frame = CGRectMake(Scale(40),Scale(16),Scale(130),Scale(22));
    titleLabel.numberOfLines = 0;
    titleLabel.attributedText = [[NSMutableAttributedString alloc] initWithString:title attributes: @{NSFontAttributeName: [UIFont systemFontOfSize: 16],NSForegroundColorAttributeName: [UIColor colorWithRed:37/255.0 green:48/255.0 blue:68/255.0 alpha:1.0]}];
    [cell.contentView addSubview:titleLabel];
    
    
    UIView *grayLine = [[UIView alloc] init];
    grayLine.layer.backgroundColor = [UIColor colorWithRed:238/255.0 green:239/255.0 blue:247/255.0 alpha:1.0].CGColor;
    [cell.contentView addSubview:grayLine];
    [grayLine mas_makeConstraints:^(MASConstraintMaker *make) {
        make.bottom.equalTo(cell.contentView.mas_bottom);
        make.height.mas_equalTo(Scale(10));
        make.left.right.equalTo(cell.contentView);
    }];
    return cell;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    
    return 4;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    switch (indexPath.row) {
        case 0:
        {
            if (![self.dataSource[@"events"] count]) {
                return Scale(296);
            } else {
                NSInteger eventRow = 1 + ([self.dataSource[@"events"] count] - 1)/2;
                return Scale(155+34*eventRow+(eventRow - 1)*12);
            }
        }
            break;
        case 1:
        {
            NSArray *tags = self.dataSource[@"tag"];
            return Scale(89 + 60*tags.count);
        }
        case 2:
        {
            if (![self.dataSource[@"channels"] count]) {
                return Scale(259);
            } else {
                NSArray *channels = self.dataSource[@"channels"];
                return Scale(81 + 76*channels.count);
            }
        }
        case 3:
        {
            NSArray *userProperties = self.dataSource[@"user"];
            return Scale(64 + 60*userProperties.count);
        }
    }
    return 10;
}

- (void)eventTap:(UITapGestureRecognizer *)tap {
    NSString *eventName = self.dataSource[@"events"][tap.view.tag][@"name"];
    JOPERATEEventObject * event = [[JOPERATEEventObject alloc] init];
    event.eventName = eventName;
    [JOPERATEService eventRecord:event];
}

- (void)editUserID:(UIButton*)sender  {
    NSArray *tags = self.dataSource[@"tag"];
    NSDictionary *tag = tags[sender.tag];
    [self edit:0 param:tag];
}

- (void)editUserChannels:(UIButton*)sender  {
    NSArray *channels = self.dataSource[@"channels"];
    NSDictionary *channel = channels[sender.tag];
    [self edit:1 param:channel];
}

- (void)editUserProperties:(UIButton*)sender  {
    NSArray *users = self.dataSource[@"user"];
    NSDictionary *user = users[sender.tag];
    [self edit:2 param:user];
}


- (void)edit:(NSInteger)type
     param:(NSDictionary*)param  {
    JOPERATEPopView *popView = [[JOPERATEPopView alloc] init];
    popView.type = type;
    popView.maxCount  = 40;
    if (type == 0) {
        NSLog(@"用户标识编辑");
        popView.title = param[@"displayName"];
        popView.tipMessage = @"请输入标识值，一次只能设置一个标识值";
        popView.placeholder =  [NSString stringWithFormat:@"请输入%@", param[@"displayName"]];
        popView.text = @"";
    }else if (type == 1) {
        NSLog(@"渠道编辑");
        popView.title = [NSString stringWithFormat:@"设置「%@」通道值", param[@"channelname"]];
        popView.placeholder = @"请输入通道值";
        popView.tipMessage = @"";
        popView.text = param[@"channelvalue"];
        NSString *name = param[@"channelname"];
        NSString *type = param[@"type"];
        
        if ([type isEqualToString:@"WECHATOA"]) {
            name = @"微信公众号";
        } else if ([type isEqualToString:@"WECHATTMP"]) {
            name = @"微信小程序";
        } else if ([type isEqualToString:@"PUSH"]) {
            name = @"app通知";
        } else if ([type isEqualToString:@"EMAIL"]) {
            name = @"邮件";
        } else if ([type isEqualToString:@"SMS"]) {
            name = @"短信";
        } else if ([type isEqualToString:@"DINGTALK"]) {
            name = @"钉钉";
        } else if ([type isEqualToString:@"ALIPAYLIFE"]) {
            name = @"支付宝";
        }
        popView.icon = name;
        
    } else if (type == 2) {
        NSLog(@"用户属性编辑");
        popView.title = [NSString stringWithFormat:@"设置「%@」属性值", param[@"displayName"]];
//        "key":"jg_first_visit_time", // 用户属性的key
//        "displayName":"string", //用户属性展示名称
//        "value":"1639728225160", // 用户属性的value(如果数据类型时list类型的，属性值用逗号连接起来)
//      "type":1, //属性规则 1：覆盖，2：累加，3：仅一次
//        "unit":"", // 属性值单位
//        "datatype":"datetime" // 用户属性值类型: string/number/bool/datetime
        NSString* editType = param[@"datatype"];
        popView.placeholder = @"请输入属性值";
        if ([editType isEqualToString:@"datetime"]) {
            popView.placeholder = @"输入日期，格式yyyy-MM-dd";
        } else if ([editType isEqualToString:@"list"]) {
            popView.placeholder = @"请输入属性值,使用[,]分隔开";
            popView.subType = 3;
        } else if ([editType isEqualToString:@"bool"]) {
            popView.placeholder = @"";
            popView.title = [NSString stringWithFormat:@"选择「%@」布尔值", param[@"displayName"]];
            popView.subType = 2;
        }
        popView.tipMessage = @"";
        if ([editType isEqualToString:@"list"]) {
            if ([param[@"value"] isKindOfClass:[NSArray class]]) {
                popView.text = [param[@"value"] componentsJoinedByString:@","];
            } else {
                popView.text = @"";
            }
        } else if ([editType isEqualToString:@"datetime"]) {
            if ([param[@"value"] isKindOfClass:[NSString class]]) {
                popView.text = [self timeintervalToStr:param[@"value"]];
            }
        } else {
            popView.text = [NSString stringWithFormat:@"%@", param[@"value"]];
        }
    }
    [popView show];
    
    __weak JOPERATEPopView *weakPopView = popView;
    popView.popViewBlock = ^(NSInteger type,NSString *content, BOOL isSuccess) {
        NSLog(@"%@", content);
        [weakPopView dismiss];
        if (type == 0) {
            JOPERATEUserID *userID = [[JOPERATEUserID alloc] init];
            userID.completion = ^(NSInteger errcode, NSString * _Nonnull msg) {
                [self loadDataWith:errcode];
            };
            userID.userIDs = @{param[@"identityName"] : content};
            [JOPERATEService identifyAccount:userID];
        }else if (type == 1) {
            JOPERATEUserChannel *channel = [[JOPERATEUserChannel alloc] init];
            channel.channels = @{param[@"channelid"]: @{param[@"channelkey"] : content}};
            channel.completion = ^(NSInteger errcode, NSString * _Nonnull msg) {
                [self loadDataWith:errcode];
            };
            [JOPERATEService setUserChannel:channel];
        } else if (type == 2) {
            NSString* editType = param[@"datatype"];
            NSInteger type = [param[@"type"] integerValue];
            if ([editType isEqualToString:@"number"]) {
                NSNumber  *number = [NSNumber numberWithDouble:[content doubleValue]];
                if (type == 1) {
                    [JOPERATEService set:@{param[@"key"]: number} completion:^(NSInteger errcode, NSString * _Nonnull msg) {
                        [self loadDataWith:errcode];
                    }];
                } else {
                    [JOPERATEService increment:param[@"key"] by:number completion:^(NSInteger errcode, NSString * _Nonnull msg) {
                        [self loadDataWith:errcode];
                    }];
                }
            }else if ([editType isEqualToString:@"datetime"]) {
                NSDate *someDay = [self strToDate:content];
                if (someDay) {
                    [JOPERATEService set:@{param[@"key"]: @([someDay timeIntervalSince1970]*1000)} completion:^(NSInteger errcode, NSString * _Nonnull msg) {
                        [self loadDataWith:errcode];
                    }];
                }
            } else if ([editType isEqualToString:@"list"]) {
                NSArray *arr = [content componentsSeparatedByString:@","];
                [JOPERATEService set:@{param[@"key"]: arr} completion:^(NSInteger errcode, NSString * _Nonnull msg) {
                    [self loadDataWith:errcode];
                }];
            } else if ([editType isEqualToString:@"bool"]) {
                NSNumber  *number = [NSNumber numberWithDouble:[content doubleValue]];
                [JOPERATEService set:@{param[@"key"]: number} completion:^(NSInteger errcode, NSString * _Nonnull msg) {
                    [self loadDataWith:errcode];
                }];
            } else {
                [JOPERATEService set:@{param[@"key"]: content} completion:^(NSInteger errcode, NSString * _Nonnull msg) {
                    [self loadDataWith:errcode];
                }];
            }
        }
    };
}

- (void)loadDataWith:(NSInteger)errcode {
    if (!errcode) {
        [self loadData];
    }  else {
        dispatch_async(dispatch_get_main_queue(), ^{
            [Toast showMessage:@"设置失败" superView:self.view];
        });
    }
}

- (NSString *)timeintervalToStr: (NSString *)timeinterval {
    NSDate * date = [NSDate dateWithTimeIntervalSince1970:[timeinterval integerValue]/1000];
    NSDateFormatter *formatter = [[NSDateFormatter alloc] init];
    [formatter setDateFormat:@"yyyy-MM-dd"];
    [formatter setTimeZone:[NSTimeZone timeZoneWithAbbreviation:@"UTC"]];
    return  [formatter stringFromDate:date];
}

- (NSDate *)strToDate: (NSString *)str  {
    NSDateFormatter *formatter = [[NSDateFormatter alloc] init];
    [formatter setDateFormat:@"yyyy-MM-dd"];
    [formatter setTimeZone:[NSTimeZone timeZoneWithAbbreviation:@"UTC"]];
    NSDate *someDay = [formatter dateFromString:str];
    return someDay;
}

@end
