//
//  ProjectInfoController.m
//  JOperateDemo
//
//  Created by ys on 2021/11/26.
//

#import "ProjectInfoController.h"
#import "AppDelegate.h"
#import "JOPERATEService.h"

@interface ProjectInfoController ()<UITableViewDelegate, UITableViewDataSource>

@property(nonatomic, strong) NavBar *navbar;
@property(nonatomic, strong) UITableView *tableView;
@property(nonatomic, strong) NSMutableArray *dataSource;
@property(nonatomic, strong) NSDictionary *appInfo;

@end

@implementation ProjectInfoController


- (void)viewDidLoad {
    [super viewDidLoad];
    self.navbar = [[NavBar alloc] initWithTitle:@"项目信息" delegate:self withBack:YES];
    [self.view addSubview:self.navbar];
    self.view.backgroundColor = UIColor.whiteColor;
    
    [self loadData];
    [self layout];
}

- (void)layout {
    self.tableView = [[UITableView alloc] init];
    self.tableView.delegate = self;
    self.tableView.dataSource = self;
    self.tableView.backgroundColor = kUIColorFromRGB(0xF6F7F8);
    self.tableView.separatorStyle = UITableViewCellSeparatorStyleNone;
    [self.tableView registerClass:[UITableViewCell class] forCellReuseIdentifier:@"cell"];
    [self.view addSubview:self.tableView];
    
    [self.tableView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(self.navbar.mas_bottom);
        make.left.width.bottom.equalTo(self.view);
    }];
}

- (void)loadData {
    self.dataSource = [@[
        @{@"数据源平台":@"iOS"},
        @{@"数据源名称":@"JOperateDemo"},
          @{@"AppKey":APP_KEY},
            @{@"Bundle ID":[NSBundle mainBundle].bundleIdentifier},
              @{@"运营增长SDK版本":@"2.0.8"},
    ]  mutableCopy];
    [JOPERATEService appInfo:^(NSInteger code, NSDictionary<NSString *,id> * _Nonnull data) {
        if (!code && data) {
            self.appInfo = data;
            dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(0 * NSEC_PER_SEC)), dispatch_get_main_queue(), ^{
                [self.tableView reloadData];
            });
        }
    }];
}


- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell * cell = [tableView dequeueReusableCellWithIdentifier:@"cell"];
    cell.selectionStyle = UITableViewCellSelectionStyleNone;
    [cell.contentView.subviews makeObjectsPerformSelector:@selector(removeFromSuperview)];
    
    if (indexPath.row == 0) {
        NSString *pName = @"获取中...";
        NSString *pID = @"获取中...";
        NSString *pCount = @"获取中...";
        if (self.appInfo) {
            pName = self.appInfo[@"name"];
            pID = self.appInfo[@"id"];
            pCount = self.appInfo[@"eventStoreCount"];
        }
        
        cell.contentView.backgroundColor = kUIColorFromRGB(0xF6F7F8);
        UIImageView *backView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"项目信息背景"]];
        backView.backgroundColor = UIColor.whiteColor;
        backView.frame = CGRectMake(0,Scale(10),Scale(375),Scale(190));
        [cell.contentView addSubview:backView];
        
        UIImageView *iconView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"项目icon"]];
        iconView.frame = CGRectMake(Scale(156),Scale(36),Scale(62),Scale(62));
        [cell.contentView addSubview:iconView];
        
        UILabel *projectLabel = [[UILabel alloc] init];
        projectLabel.attributedText = [[NSMutableAttributedString alloc] initWithString:pName attributes: @{NSFontAttributeName: [UIFont systemFontOfSize: 18],NSForegroundColorAttributeName: kUIColorFromRGB(0x253044)}];
        projectLabel.alpha = 0.9;
        [cell.contentView addSubview:projectLabel];
        [projectLabel mas_makeConstraints:^(MASConstraintMaker *make) {
            make.centerX.equalTo(cell.contentView);
            make.top.equalTo(cell.contentView).offset(Scale(108));
        }];
        
        UILabel *projectIDLabel = [[UILabel alloc] init];
        projectIDLabel.attributedText = [[NSMutableAttributedString alloc] initWithString:[NSString stringWithFormat:@"项目ID：%@", pID]attributes: @{NSFontAttributeName: [UIFont systemFontOfSize: 14],NSForegroundColorAttributeName: kUIColorFromRGB(0x6B7381)}];
        [cell.contentView addSubview:projectIDLabel];
        UIButton *copyBtn = [[UIButton alloc] init];
        [copyBtn setImage:[UIImage imageNamed:@"复制"] forState:UIControlStateNormal];
        [copyBtn addTarget:self action:@selector(copypid) forControlEvents:UIControlEventTouchUpInside];
        [cell.contentView addSubview:copyBtn];
        
        [projectIDLabel mas_makeConstraints:^(MASConstraintMaker *make) {
            make.centerX.equalTo(cell.contentView);
            make.top.equalTo(cell.contentView).offset(Scale(143));
        }];
        [copyBtn mas_makeConstraints:^(MASConstraintMaker *make) {
            make.width.and.height.mas_equalTo(Scale(20.0));
            make.centerY.equalTo(projectIDLabel);
            make.left.equalTo(projectIDLabel.mas_right).offset(Scale(5));
        }];

        UIView *totalView = [[UIView alloc] init];
        totalView.frame = CGRectMake(Scale(16),Scale(185),Scale(343),Scale(41));
        totalView.layer.backgroundColor = [UIColor colorWithRed:41/255.0 green:152/255.0 blue:253/255.0 alpha:1.0].CGColor;
        totalView.layer.cornerRadius = 6;
        totalView.layer.shadowColor = [UIColor colorWithRed:0/255.0 green:99/255.0 blue:190/255.0 alpha:0.32].CGColor;
        totalView.layer.shadowOffset = CGSizeMake(0,1);
        totalView.layer.shadowOpacity = 1;
        totalView.layer.shadowRadius = 6;
        [cell.contentView addSubview:totalView];
        
        UILabel *totalLabel = [[UILabel alloc] init];
        totalLabel.frame = CGRectMake(Scale(31),Scale(196),Scale(120),Scale(20));
        [cell.contentView addSubview:totalLabel];
        totalLabel.attributedText = [[NSMutableAttributedString alloc] initWithString:@"项目事件上报总量"attributes: @{NSFontAttributeName: [UIFont systemFontOfSize: 14],NSForegroundColorAttributeName: UIColor.whiteColor}];;
        
        UILabel *totalValueLabel = [[UILabel alloc] init];
        [cell.contentView addSubview:totalValueLabel];
        totalValueLabel.attributedText = [[NSMutableAttributedString alloc] initWithString:[NSString stringWithFormat:@"%@个", pCount] attributes: @{NSFontAttributeName: [UIFont systemFontOfSize: 14],NSForegroundColorAttributeName: UIColor.whiteColor}];
        [totalValueLabel sizeToFit];
        [totalValueLabel mas_makeConstraints:^(MASConstraintMaker *make) {
            make.centerY.equalTo(totalLabel);
            make.right.equalTo(cell.contentView).offset(Scale(-30));
        }];

        UIView *titleView = [[UIView alloc] initWithFrame:CGRectMake(0, Scale(240), Scale(375), Scale(49))];
        titleView.backgroundColor = UIColor.whiteColor;
        [cell.contentView addSubview:titleView];
        
        UILabel *titleLabel = [[UILabel alloc] init];
        titleLabel.frame = CGRectMake(Scale(16),Scale(260),Scale(130),Scale(22));
        titleLabel.numberOfLines = 0;
        titleLabel.attributedText = [[NSMutableAttributedString alloc] initWithString:@"数据源信息" attributes: @{NSFontAttributeName: [UIFont systemFontOfSize: 16],NSForegroundColorAttributeName: [UIColor colorWithRed:37/255.0 green:48/255.0 blue:68/255.0 alpha:1.0]}];
        [cell.contentView addSubview:titleLabel];
        
    } else if (indexPath.row < self.dataSource.count + 1) {
        NSDictionary *data = self.dataSource[indexPath.row - 1];
        UILabel *label = [[UILabel alloc] init];
        label.frame = CGRectMake(Scale(16), Scale(20), Scale(130), Scale(20));
        [cell.contentView addSubview:label];
        label.attributedText = [[NSMutableAttributedString alloc] initWithString:data.allKeys[0] attributes: @{NSFontAttributeName: [UIFont systemFontOfSize: 14],NSForegroundColorAttributeName: kUIColorFromRGB(0x6B7381)}];
       
        UILabel *valueLabel = [[UILabel alloc] init];
        valueLabel.textColor = kUIColorFromRGB(0x253044);
        valueLabel.font = [UIFont systemFontOfSize:12.0];
        valueLabel.textAlignment = NSTextAlignmentRight;
        valueLabel.text = data.allValues[0];
        [cell.contentView addSubview:valueLabel];
        
        [valueLabel mas_makeConstraints:^(MASConstraintMaker *make) {
            make.height.equalTo(label.mas_height);
            make.centerY.equalTo(label.mas_centerY);
            make.right.equalTo(cell.contentView).offset(-Scale(16));
        }];
        
        UIView *line = [[UIView alloc] init];
        line.layer.backgroundColor = [UIColor colorWithRed:238/255.0 green:239/255.0 blue:247/255.0 alpha:1.0].CGColor;
        [cell.contentView addSubview:line];
        [line mas_makeConstraints:^(MASConstraintMaker *make) {
            make.height.mas_equalTo(Scale(1));
            make.left.equalTo(cell.contentView.mas_left).offset(Scale(16));
            make.right.equalTo(cell.contentView.mas_right).offset(Scale(-16));
            make.bottom.equalTo(cell.contentView);
        }];
        cell.contentView.backgroundColor = UIColor.whiteColor   ;
    } else {
        cell.contentView.backgroundColor = kUIColorFromRGB(0xF6F7F8);
        UIImageView * logoImageView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"logo"]];
        logoImageView.frame = CGRectMake(Scale(137), Scale(40), Scale(103), Scale(16));
        [cell.contentView addSubview:logoImageView];
    }
    return cell;
}




- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    
    return self.dataSource.count + 2;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    if (indexPath.row == 0) {
        return Scale(288);
    }
    return Scale(60);
}


- (void)copypid {
    if (self.appInfo) {
        [UIPasteboard generalPasteboard].string = [NSString stringWithFormat:@"%@", self.appInfo[@"id"]];
        [Toast showMessage:@"复制成功" superView:self.view];
    }
}


@end
