//
//  ViewController.m
//  JOperateDemo
//
//  Created by ys on 2021/7/2.
//

#import "ViewController.h"
#import "JOPERATEService.h"
#import "Masonry/Masonry.h"
#import "AdvancedController.h"
#import "PresetController.h"
#import "ProjectInfoController.h"

@interface ViewController ()

@property(nonatomic, strong) UIView * unbindView;
@property(nonatomic, strong) UIView * mainView;
@property(nonatomic, strong) UIView * navbar;
@property(nonatomic, strong) UILabel * debugStatusLabel;
@property(nonatomic, strong) UIView * debugStatusPoint;
@property(nonatomic, strong) UIButton * debugBtn;
@property(nonatomic, strong) UILabel * promptLabel;
@property(nonatomic, strong) UILabel * cuidContentLabel;
@property(nonatomic, assign) BOOL isDebugMode;

@end

@implementation ViewController

- (void)viewDidAppear:(BOOL)animated{
    [super viewDidAppear:animated];
    self.navigationController.navigationBar.hidden = YES;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    
    [[NSNotificationCenter defaultCenter]  addObserver:self selector:@selector(debugModeNotification) name:@"joperate_debug" object:nil];
    
    self.navbar = [[NavBar alloc] initWithTitle:@"极光运营增长" delegate:self withBack:NO];
    [self.navbar setHidden:YES];
    [self.view addSubview:self.navbar];
    [self layoutUnbindView];
    
    [JOPERATEService isValid:^(NSInteger code, NSString * _Nonnull msg) {
        if (!code) {
            [self.mainView removeFromSuperview];
            [self layoutMainView];
            self.cuidContentLabel.text = [JOPERATEService CUID]?:@"暂无";
        }
    }];
}

- (void)layoutMainView {
    self.mainView = [[UIView alloc] initWithFrame:self.view.bounds];
    self.mainView.backgroundColor = [UIColor whiteColor];
    [self.view addSubview:self.mainView];

    UIImageView * backImageView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"智能运营背景"]];
    backImageView.frame = CGRectMake(0, 0, Scale(375), Scale(320));
    [self.mainView addSubview:backImageView];
    
    UILabel *titleLabel = [[UILabel alloc] init];
    titleLabel.attributedText = [[NSMutableAttributedString alloc] initWithString:@"极光运营增长"attributes: @{NSFontAttributeName: [UIFont boldSystemFontOfSize:24],NSForegroundColorAttributeName: [UIColor colorWithRed:255/255.0 green:255/255.0 blue:255/255.0 alpha:1.0]}];
    [self.mainView addSubview:titleLabel];
    [titleLabel  mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(self.mainView).offset(Scale((80)));
        make.left.equalTo(self.mainView).offset(Scale((16)));
    }];
    
    UILabel *descLabel = [[UILabel alloc] init];
    descLabel.attributedText = [[NSMutableAttributedString alloc] initWithString:@"专注提升运营效果、运营效率"attributes: @{NSFontAttributeName: [UIFont systemFontOfSize: 13],NSForegroundColorAttributeName: [UIColor colorWithRed:255/255.0 green:255/255.0 blue:255/255.0 alpha:1.0]}];
    [self.mainView addSubview:descLabel];
    [descLabel  mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(self.mainView).offset(Scale((119)));
        make.left.equalTo(self.mainView).offset(Scale((16)));
    }];
    
    UIView * whiteRoundView = [[UIView alloc] initWithFrame:CGRectMake(0, Scale(234), DeviceSize.width, self.view.frame.size.height - Scale(234))];
    whiteRoundView.backgroundColor = UIColor.whiteColor;
    whiteRoundView.layer.cornerRadius = Scale(6);
    whiteRoundView.layer.masksToBounds = true;
    [self.mainView addSubview:whiteRoundView];
    
    UILabel *cuidLabel = [[UILabel alloc] init];
    cuidLabel.font = [UIFont systemFontOfSize:14.0];
    cuidLabel.numberOfLines = 0;
    cuidLabel.text = @"CUID";
    [self.mainView addSubview:cuidLabel];
    [cuidLabel mas_makeConstraints:^(MASConstraintMaker *make) {
        make.width.mas_equalTo(Scale(100));
        make.height.mas_equalTo(Scale(20));
        make.left.equalTo(self.mainView).offset(Scale(16.1));
        make.top.equalTo(self.mainView).offset(Scale(268));
    }];

    self.cuidContentLabel = [[UILabel alloc] init];
    self.cuidContentLabel.numberOfLines = 0;
    self.cuidContentLabel.textColor = [UIColor colorWithRed:141/255.0 green:147/255.0 blue:157/255.0 alpha:1.0];
    self.cuidContentLabel.font = [UIFont systemFontOfSize:12.0];
    self.cuidContentLabel.textAlignment = NSTextAlignmentRight;
    self.cuidContentLabel.text = [JOPERATEService CUID]?:@"暂无";
    [self.mainView addSubview:self.cuidContentLabel];
    
    UIButton *copyBtn = [[UIButton alloc] init];
    [copyBtn setImage:[UIImage imageNamed:@"复制"] forState:UIControlStateNormal];
    [copyBtn addTarget:self action:@selector(copycuid) forControlEvents:UIControlEventTouchUpInside];
    [self.mainView addSubview:copyBtn];
    
    [self.cuidContentLabel mas_makeConstraints:^(MASConstraintMaker *make) {
        make.height.equalTo(cuidLabel.mas_height);
        make.centerY.equalTo(cuidLabel.mas_centerY);
        make.left.equalTo(cuidLabel.mas_right).offset(Scale(10));
        make.right.equalTo(copyBtn.mas_left).offset(Scale(-3));

    }];
    [copyBtn mas_makeConstraints:^(MASConstraintMaker *make) {
        make.width.and.height.mas_equalTo(Scale(20.0));
        make.centerY.equalTo(cuidLabel.mas_centerY);
        make.right.equalTo(self.mainView.mas_right).offset(Scale(-16));
    }];
    
    UIView *line = [[UIView alloc] init];
    line.layer.backgroundColor = [UIColor colorWithRed:238/255.0 green:239/255.0 blue:247/255.0 alpha:1.0].CGColor;
    [self.mainView addSubview:line];
    
    [line mas_makeConstraints:^(MASConstraintMaker *make) {
        make.height.mas_equalTo(Scale(1));
        make.left.equalTo(self.mainView.mas_left).offset(Scale(16));
        make.right.equalTo(self.mainView.mas_right).offset(Scale(-16));
        make.top.equalTo(cuidLabel.mas_bottom).offset(Scale(16));
    }];

    UILabel *debugLabel = [[UILabel alloc] init];
    debugLabel.font = [UIFont systemFontOfSize:14.0];
    debugLabel.text = @"数据校验模式";
    [self.mainView addSubview:debugLabel];
    [debugLabel mas_makeConstraints:^(MASConstraintMaker *make) {
        make.width.mas_equalTo(Scale(105));
        make.height.mas_equalTo(Scale(20));
        make.left.equalTo(self.mainView).offset(Scale(16.1));
        make.top.equalTo(self.mainView).offset(Scale(323));
    }];
    
    self.debugStatusLabel = [[UILabel alloc] init];
    self.debugStatusLabel.tag = 1;
    self.debugStatusLabel.font = [UIFont systemFontOfSize:13.0];
    self.debugStatusLabel.text = @"未开启";
    self.debugStatusLabel.textColor = kUIColorFromRGB(0x8D939D);
    [self.mainView addSubview:self.debugStatusLabel];
    [self.debugStatusLabel mas_makeConstraints:^(MASConstraintMaker *make) {
        make.right.equalTo(self.mainView).offset(Scale(-16));
        make.centerY.equalTo(debugLabel);
    }];
    self.debugStatusPoint = [[UIView alloc] init];
    self.debugStatusPoint.backgroundColor = kUIColorFromRGB(0x8D939D);
    self.debugStatusPoint.layer.cornerRadius = 2;
    [self.mainView addSubview:self.debugStatusPoint];
    [self.debugStatusPoint mas_makeConstraints:^(MASConstraintMaker *make) {
        make.right.equalTo(self.debugStatusLabel.mas_left).offset(Scale(-5));
        make.centerY.equalTo(debugLabel);
        make.size.mas_equalTo(4);
    }];
    
    
    self.debugBtn = [[UIButton alloc] init];
    [self.debugBtn setBackgroundImage:[UIImage imageNamed:@"btn_42px"] forState:UIControlStateNormal];
    [self.debugBtn setTitle:@"扫码进入数据校验模式" forState:UIControlStateNormal];
    self.debugBtn.titleLabel.font = [UIFont systemFontOfSize:14];
    self.debugBtn.layer.cornerRadius = Scale(42) / 2;
    [self.debugBtn setImage:[UIImage imageNamed:@"扫码"] forState:UIControlStateNormal];
    self.debugBtn.layer.masksToBounds = true;
    [self.debugBtn addTarget:self action:@selector(toDebugModeOrAdvanced) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:self.debugBtn];
    [self.debugBtn mas_makeConstraints:^(MASConstraintMaker *make) {
        make.size.mas_equalTo(CGSizeMake(Scale(260), Scale(42)));
        make.left.equalTo(self.mainView).offset(Scale(58));
        make.top.equalTo(self.debugStatusLabel.mas_bottom).offset(Scale(30));
    }];
    
    UIImageView *promptImage = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"首页提示"]];
    [self.mainView addSubview:promptImage];
    [promptImage mas_makeConstraints:^(MASConstraintMaker *make) {
        make.size.mas_equalTo(Scale(12));
        make.left.equalTo(self.mainView).offset(Scale(19));
        make.top.equalTo(self.debugStatusLabel.mas_bottom).offset(Scale(87));
    }];
    
    self.promptLabel = [[UILabel alloc] init];
    self.promptLabel.textColor = [UIColor colorWithRed:141/255.0 green:147/255.0 blue:157/255.0 alpha:1.0];
    self.promptLabel.font = [UIFont systemFontOfSize:Scale(12.0)];
    self.promptLabel.textAlignment = NSTextAlignmentRight;
    self.promptLabel.text = @"在「数据中心-接入校验」页，点击「扫码获取」弹出二维码";
    //在「高级功能」中产生的相关用户行为数据不会进入生产环境
    [self.mainView addSubview:self.promptLabel];

    [self.promptLabel mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(self.debugBtn.mas_bottom).offset(Scale(14));
        make.centerY.equalTo(promptImage.mas_centerY);
        make.left.equalTo(promptImage.mas_right).offset(Scale(4));
    }];
    
    UIView *grayLine = [[UIView alloc] init];
    grayLine.layer.backgroundColor = [UIColor colorWithRed:238/255.0 green:239/255.0 blue:247/255.0 alpha:1.0].CGColor;
    [self.mainView addSubview:grayLine];
    [grayLine mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(self.debugBtn.mas_bottom).offset(Scale(60));
        make.height.mas_equalTo(Scale(10));
        make.left.right.equalTo(self.mainView);
    }];
        
    UIButton *presetBtn = [[UIButton alloc] init];
    presetBtn.backgroundColor = [UIColor whiteColor];
    [presetBtn setTitleColor:[UIColor colorWithRed:0/255.0 green:132/255.0 blue:246/255.0 alpha:1.0] forState:UIControlStateNormal];
    [presetBtn setTitle:@"预置事件属性" forState:UIControlStateNormal];
    presetBtn.titleLabel.font = [UIFont systemFontOfSize:14];
    presetBtn.layer.cornerRadius = Scale(42) / 2;
    presetBtn.layer.masksToBounds = true;
    presetBtn.layer.borderWidth = 1.0;
    presetBtn.layer.borderColor = [UIColor colorWithRed:0/255.0 green:132/255.0 blue:246/255.0 alpha:1.0].CGColor;
    [presetBtn addTarget:self action:@selector(toPreset) forControlEvents:UIControlEventTouchUpInside];
    [self.mainView addSubview:presetBtn];
    [presetBtn mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(self.debugBtn.mas_bottom).offset(Scale(100));
        make.size.mas_equalTo(CGSizeMake(Scale(260),Scale(42)));
        make.left.equalTo(self.mainView).offset(Scale(58));
    }];
    
    UIButton *projectBtn = [[UIButton alloc] init];
    projectBtn.backgroundColor = [UIColor whiteColor];
    [projectBtn setTitleColor:[UIColor colorWithRed:0/255.0 green:132/255.0 blue:246/255.0 alpha:1.0] forState:UIControlStateNormal];
    [projectBtn setTitle:@"项目信息" forState:UIControlStateNormal];
    projectBtn.titleLabel.font = [UIFont systemFontOfSize:14];
    projectBtn.layer.cornerRadius = Scale(42) / 2;
    projectBtn.layer.masksToBounds = true;
    projectBtn.layer.borderWidth = 1.0;
    projectBtn.layer.borderColor = [UIColor colorWithRed:0/255.0 green:132/255.0 blue:246/255.0 alpha:1.0].CGColor;
    [projectBtn addTarget:self action:@selector(toProject) forControlEvents:UIControlEventTouchUpInside];
    [self.mainView addSubview:projectBtn];
    [projectBtn mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(self.debugBtn.mas_bottom).offset(Scale(162));
        make.size.mas_equalTo(CGSizeMake(Scale(260),Scale(42)));
        make.left.equalTo(self.mainView).offset(Scale(58));
    }];
 
    UIImageView * logoImageView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"logo"]];
    [self.view addSubview:logoImageView];
    [logoImageView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(projectBtn.mas_bottom).offset(Scale(23));
        make.centerX.equalTo(projectBtn);
    }];

}


- (void)layoutUnbindView {
    self.unbindView = [[UIView alloc] init];
    self.unbindView.backgroundColor = [UIColor whiteColor];
    [self.view addSubview:self.unbindView];
    
    UIImageView *imageView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"开通背景图"]];
    [self.unbindView addSubview:imageView];
    
    UILabel *label1 = [[UILabel alloc] init];
    label1.numberOfLines = 0;
    label1.textAlignment = NSTextAlignmentCenter;
    label1.attributedText = [[NSMutableAttributedString alloc] initWithString:@"该应用尚未被添加到任何运营增长项目" attributes: @{NSFontAttributeName: [UIFont boldSystemFontOfSize:16],NSForegroundColorAttributeName: [UIColor colorWithRed:37/255.0 green:48/255.0 blue:68/255.0 alpha:1.0]}];
    [self.unbindView addSubview:label1];
    
    UILabel *label2 = [[UILabel alloc] init];
    label2.numberOfLines = 0;
    label2.attributedText = [[NSMutableAttributedString alloc] initWithString:@"请在「极光运营增长-数据中心-数据通道连接」添加本应用为数据源，方可正常使用" attributes: @{NSFontAttributeName: [UIFont systemFontOfSize: 14],NSForegroundColorAttributeName: [UIColor colorWithRed:141/255.0 green:147/255.0 blue:157/255.0 alpha:1.0]}];
    label2.textAlignment = NSTextAlignmentCenter;
    [self.unbindView addSubview:label2];
    
    UIView *bottomView = [[UIView alloc] init];
    bottomView.backgroundColor = [UIColor colorWithRed:245/255.0 green:245/255.0 blue:245/255.0 alpha:1.0];
    [self.unbindView addSubview:bottomView];
    
    UIImageView *logoImageView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"logo"]];
    [self.unbindView addSubview:logoImageView];
    
    [self.unbindView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.left.bottom.width.equalTo(self.view);
        make.top.equalTo(self.navbar.mas_bottom);
    }];

    [imageView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.size.mas_equalTo(CGSizeMake(259, 162));
        make.top.equalTo(self.unbindView).offset(58);
        make.centerX.equalTo(self.unbindView);
    }];
    [label1 mas_makeConstraints:^(MASConstraintMaker *make) {
        make.size.mas_equalTo(CGSizeMake(280, 22));
        make.top.equalTo(imageView.mas_bottom).offset(26);
        make.centerX.equalTo(self.unbindView);
    }];
    [label2 mas_makeConstraints:^(MASConstraintMaker *make) {
        make.size.mas_equalTo(CGSizeMake(295, 49));
        make.top.equalTo(label1.mas_bottom).offset(12);
        make.centerX.equalTo(self.unbindView);
    }];
    [bottomView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.width.bottom.left.equalTo(self.unbindView);
        make.height.mas_equalTo(130);
    }];
    [logoImageView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(bottomView).offset(Scale(19));
        make.centerX.equalTo(bottomView);
    }];
    
    
}

- (void)copycuid {
    [UIPasteboard generalPasteboard].string = [JOPERATEService CUID];
    [Toast showMessage:@"复制成功" superView:self.view];
}

- (void)toDebugModeOrAdvanced {
    if (self.isDebugMode) {
        [self.navigationController pushViewController:[[AdvancedController alloc] init] animated:YES];;
    } else {
        [Toast showMessage:@"请打开系统相机扫描官方数据校验模式二维码打开应用" superView:self.view];
    }
}

- (void)toPreset {
    [self.navigationController pushViewController:[[PresetController alloc] init] animated:YES];;
}

- (void)toProject {
    [self.navigationController pushViewController:[[ProjectInfoController alloc] init] animated:YES];
}

- (void)debugModeNotification {
    self.isDebugMode = YES;
    self.debugStatusLabel.text = @"已开启";
    self.debugStatusLabel.textColor = kUIColorFromRGB(0x0084F6);
    self.debugStatusPoint.backgroundColor = kUIColorFromRGB(0x0084F6);
    
    [self.debugBtn setTitle:@"高级功能（调试）" forState:UIControlStateNormal];
    [self.debugBtn setImage:[UIImage imageNamed:@"高级功能"] forState:UIControlStateNormal];
    self.promptLabel.text = @"在「高级功能」中产生的相关用户行为数据不会进入生产环境";
}

@end
